@@ -44,7 +44,8 @@ class TextBlock(BaseBlock):
     name = 'Text'
 
     def clean(self, data):
-        if set(data.keys()) != {'text'}:
+        data = super(VideoBlock, self).clean(data)
+        if set(['text']) - set(data.keys()):
             raise ValidationError('Invalid data for {0} block'.format(self.name))
         return data
 
@@ -69,7 +70,8 @@ class VideoBlock(BaseBlock):
     }
 
     def clean(self, data):
-        if set(data.keys()) != {'source', 'remote_id'}:
+        data = super(VideoBlock, self).clean(data)
+        if set(['source', 'remote_id']) - set(data.keys()):
             raise ValidationError('Invalid data for {0} block'.format(self.name))
         if data['source'] not in self.providers:
             raise ValidationError('Invalid video provider')
