@@ -40,3 +40,9 @@ class SirTrevorField(JSONField):
         name, path, args, kwargs = super(SirTrevorField, self).deconstruct()
         kwargs['blocks'] = self.blocks
         return name, path, args, kwargs
+
+try:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^sirdjango\.models\.SirTrevorField"])
+except ImportError:
+    pass
