@@ -1,6 +1,6 @@
 def render_json(data, blocks):
     if isinstance(data, dict) and isinstance(data['data'], list):
-        block_map = {b.block_type: b for b in blocks}
+        block_map = dict((b.block_type, b) for b in blocks)
         return ''.join(render_block(raw_block, block_map) for raw_block in data['data'])
 
 
